==> activity-center-api-0.6.3.wb11-20170406.063637-1-sources.jar: cn/com/duiba/tuia/activity/center/api/constant/FieldNameSpace.java <==
/**
 * Project Name:activity-center-api<br>
 * File Name:FieldNameSpace.java<br>
 * Package Name:cn.com.duiba.tuia.activity.center.api.constant<br>
 * Date:2017年3月9日下午5:32:42<br>
 * Copyright (c) 2017, duiba.com.cn All Rights Reserved.<br>
 */
package cn.com.duiba.tuia.activity.center.api.constant;

/**
 * ClassName: FieldNameSpace <br/>
 * Function: 属性名常量. <br/>
 * Reason: 代码需要添写属性名时,使用此常量类. <br/>
 * date: 2017年3月9日 下午5:32:42 <br/>
 *
 * @author wubo
 * @version
 * @since JDK 1.7
 */
public class FieldNameSpace {
    /* A B C D E F G H I J K L M N O P Q R S T U V W X Y Z */        //sort

    public static final String ACTIVITYTYPE     = "activityType";
    public static final String ACTIVITYTYPENAME = "activityTypeName";
    public static final String ACTIVITYIDS      = "activityIds"; 
    public static final String ACTIVITYID       = "activityId";
    public static final String ACTIVITYPLANNER  = "activityPlanner";
    public static final String ACTIVITYAMOUNT   = "activityAmount";
    public static final String ACTCENTERAMOUNT  = "actCenterAmount";
    
    public static final String CHANNEL          = "channel";
    public static final String CURDATE          = "curDate";
    
    public static final String DATAJSON         = "dataJson";
    public static final String DATACONFIG       = "dataConfig";
    
    public static final String END              = "end";
    public static final String ENTRANCETYPE     = "entranceType";
    
    public static final String GMTCREATE        = "gmtCreate";
    public static final String GMTMODIFIED      = "gmtModified";
    
    public static final String HTML             = "html";
    
    public static final String ID               = "id";
    public static final String IDENTIFICATION   = "identification";

    public static final String LANDID           = "landId";

    public static final String MAX              = "max";
    public static final String MAINMEETAMOUNT   ="mainMeetAmount";
            
    
    public static final String OFFSET           = "offset";
    
    public static final String SKINNAME         = "skinName";
    public static final String SUBTYPE          = "subType";
    public static final String STYLECONFIG      = "styleConfig";
    public static final String SLOTIDS          = "slotIds";
    public static final String SLOTID           = "slotId";
    public static final String START            = "start";
    
    public static final String TAG              = "tag";
    public static final String TITLE            = "title";
    
    public static final String USERPHONE        = "userPhone";
    
    public static final String VISIONPLANNER    = "visionPlanner";    

    private FieldNameSpace() {
    }
}

==> activity-center-api-0.7.1.wb3-20170526.070223-1-sources.jar: cn/com/duiba/tuia/activity/center/api/constant/FieldNameSpace.java <==
/**
 * Project Name:activity-center-api<br>
 * File Name:FieldNameSpace.java<br>
 * Package Name:cn.com.duiba.tuia.activity.center.api.constant<br>
 * Date:2017年3月9日下午5:32:42<br>
 * Copyright (c) 2017, duiba.com.cn All Rights Reserved.<br>
 */
package cn.com.duiba.tuia.activity.center.api.constant;

/**
 * ClassName: FieldNameSpace <br/>
 * Function: 属性名常量. <br/>
 * Reason: 代码需要添写属性名时,使用此常量类. <br/>
 * date: 2017年3月9日 下午5:32:42 <br/>
 *
 * @author wubo
 * @version
 * @since JDK 1.7
 */
public class FieldNameSpace {
    /* A B C D E F G H I J K L M N O P Q R S T U V W X Y Z */        //sort

    public static final String ACTIVITYTYPE     = "activityType";
    public static final String ACTIVITYTYPENAME = "activityTypeName";
    public static final String ACTIVITYIDS      = "activityIds"; 
    public static final String ACTIVITYID       = "activityId";
    public static final String ACTIVITYPLANNER  = "activityPlanner";
    public static final String ACTIVITYAMOUNT   = "activityAmount";
    public static final String ACTCENTERAMOUNT  = "actCenterAmount";
    
    public static final String BIRTHDAY         = "birthday";
    public static final String BUOYID           = "buoyId";
    public static final String BUOYIDS          = "buoyIds";
    
    public static final String CHANNEL          = "channel";
    public static final String CURDATE          = "curDate";
    
    public static final String DATAJSON         = "dataJson";
    public static final String DATACONFIG       = "dataConfig";
    
    public static final String END              = "end";
    public static final String ENTRANCETYPE     = "entranceType";
    
    public static final String GMTCREATE        = "gmtCreate";
    public static final String GMTMODIFIED      = "gmtModified";
    
    public static final String HTML             = "html";
    
    public static final String ID               = "id";
    public static final String IDENTIFICATION   = "identification";

    public static final String LANDID           = "landId";

    public static final String MAX              = "max";
    public static final String MAINMEETAMOUNT   ="mainMeetAmount";
            
    
    public static final String OFFSET           = "offset";
    
    public static final String SKINNAME         = "skinName";
    public static final String SUBTYPE          = "subType";
    public static final String STYLECONFIG      = "styleConfig";
    public static final String SLOTIDS          = "slotIds";
    public static final String SLOTID           = "slotId";
    public static final String START            = "start";
    
    public static final String TAG              = "tag";
    public static final String TITLE            = "title";
    
    public static final String USERPHONE        = "userPhone";
    
    public static final String VISIONPLANNER    = "visionPlanner";

    private FieldNameSpace() {
    }
}
